[Bf-blender-cvs] [543b71a30ba] asset-greasepencil: Merge branch 'master' into asset-greasepencil

Antonio Vazquez noreply at git.blender.org
Mon Dec 27 19:31:07 CET 2021


Commit: 543b71a30bacbcf9df2afc5c961b3b28e215cef9
Author: Antonio Vazquez
Date:   Mon Dec 27 19:30:48 2021 +0100
Branches: asset-greasepencil
https://developer.blender.org/rB543b71a30bacbcf9df2afc5c961b3b28e215cef9

Merge branch 'master' into asset-greasepencil

 Conflicts:
	source/blender/editors/render/render_preview.cc

===================================================================



===================================================================

diff --cc source/blender/editors/render/render_preview.cc
index 8ffc5a7813f,2b9dcdcacae..26e355536ed
--- a/source/blender/editors/render/render_preview.cc
+++ b/source/blender/editors/render/render_preview.cc
@@@ -379,11 -380,13 +382,14 @@@ static ID *duplicate_ids(ID *id, const 
      case ID_MA:
      case ID_TE:
      case ID_LA:
 +    case ID_GD:
      case ID_WO: {
        BLI_assert(BKE_previewimg_id_supports_jobs(id));
-       ID *id_copy = BKE_id_copy_ex(
-           NULL, id, NULL, LIB_ID_CREATE_LOCAL | LIB_ID_COPY_LOCALIZE | LIB_ID_COPY_NO_ANIMDATA);
+       ID *id_copy = BKE_id_copy_ex(nullptr,
+                                    id,
+                                    nullptr,
+                                    LIB_ID_CREATE_LOCAL | LIB_ID_COPY_LOCALIZE |
+                                        LIB_ID_COPY_NO_ANIMDATA);
        return id_copy;
      }
      /* These support threading, but don't need duplicating. */
@@@ -1717,11 -1618,8 +1736,11 @@@ static void icon_preview_startjob_all_s
          case ID_AC:
            action_preview_render(ip, cur_size);
            continue;
 +        case ID_GD:
 +          gpencil_preview_render(ip, cur_size);
 +          continue;
          default:
            /* Fall through to the same code as the `ip->id == NULL` case. */
            break;
        }
      }
@@@ -1717,11 -1618,8 +1736,11 @@@ static void icon_preview_startjob_all_s
 +          continue;
          default:
-           /* Fall through to the same code as the `ip->id == NULL` case. */
+           /* Fall through to the same code as the `ip->id == nullptr` case. */
            break;
        }



More information about the Bf-blender-cvs mailing list